@@ -5,9 +5,8 @@ use warnings;
 use Encode qw(decode encode);
 use Carp;
 use FFI::Platypus::Buffer;
-use FFI::Platypus::Declare;
 
-our $VERSION = 0.1000;
+our $VERSION = 0.1200;
 
 sub Open {
     my ($class, $path, $access) = @_;
@@ -45,7 +44,8 @@ sub Read {
 sub Write {
     my ($self, $buf) = @_;
     my $len = do {use bytes; length($buf)};
-    my $address = cast 'string' => 'opaque', $buf;
+    my $ffi = FFI::Platypus->new();
+    my $address = $ffi->cast('string' => 'opaque', $buf);
     return Geo::GDAL::FFI::VSIFWriteL($address, 1, $len, $self->{handle});
 }
 
@@ -94,7 +94,7 @@ string. $len is optional and by default 1.
 =head2 Write($buf)
 
 Write the Perl string $buf into the file. Returns the number of
-succesfully written bytes.
+successfully written bytes.
 
 =head1 LICENSE
 
